pub struct CallMethod {
pub action_id: String,
pub method_id: String,
pub provider_id: Option<String>,
pub data: Value,
}Expand description
Serialized arguments for the call_method server function.
Fields
action_id: Stringmethod_id: Stringprovider_id: Option<String>data: ValueTrait Implementations
Sourceimpl Clone for CallMethod
impl Clone for CallMethod
Sourcefn clone(&self) -> CallMethod
fn clone(&self) -> CallMethod
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CallMethod
impl Debug for CallMethod
Sourceimpl<'de> Deserialize<'de> for CallMethod
impl<'de> Deserialize<'de> for CallMethod
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for CallMethod
impl Serialize for CallMethod
Sourceimpl ServerFn for CallMethod
impl ServerFn for CallMethod
Sourceconst PATH: &'static str
const PATH: &'static str
A unique path for the server function’s API endpoint, relative to the host, including its prefix.
Sourcetype Client = BrowserClient
type Client = BrowserClient
The type of the HTTP client that will send the request from the client side. Read more
Sourcetype Server = BrowserMockServer
type Server = BrowserMockServer
The type of the HTTP server that will send the response from the server side. Read more
Sourcetype Protocol = Http<PostUrl, Post<JsonEncoding>>
type Protocol = Http<PostUrl, Post<JsonEncoding>>
The protocol the server function uses to communicate with the client.
Sourcetype Error = ServerFnError
type Error = ServerFnError
The type of error in the server function return.
Typically
ServerFnError, but allowed to be any type that implements FromServerFnError.Sourcetype InputStreamError = ServerFnError
type InputStreamError = ServerFnError
The type of error in the server function for stream items sent from the client to the server.
Typically
ServerFnError, but allowed to be any type that implements FromServerFnError.Sourcetype OutputStreamError = ServerFnError
type OutputStreamError = ServerFnError
The type of error in the server function for stream items sent from the server to the client.
Typically
ServerFnError, but allowed to be any type that implements FromServerFnError.Sourcefn middlewares() -> Vec<Arc<dyn Layer<<Self::Server as Server<Self::Error>>::Request, <Self::Server as Server<Self::Error>>::Response>>>
fn middlewares() -> Vec<Arc<dyn Layer<<Self::Server as Server<Self::Error>>::Request, <Self::Server as Server<Self::Error>>::Response>>>
Middleware that should be applied to this server function.
Sourceasync fn run_body(self) -> Result<(), ServerFnError>
async fn run_body(self) -> Result<(), ServerFnError>
The body of the server function. This will only run on the server.
Sourcefn url() -> &'static str
fn url() -> &'static str
Returns
Self::PATH.Auto Trait Implementations
impl Freeze for CallMethod
impl RefUnwindSafe for CallMethod
impl Send for CallMethod
impl Sync for CallMethod
impl Unpin for CallMethod
impl UnsafeUnpin for CallMethod
impl UnwindSafe for CallMethod